@@ -47,6 +47,7 @@ class SageIntacctSDK:
         self.reimbursements = Reimbursements()
         self.checking_accounts = CheckingAccounts()
         self.savings_accounts = SavingsAccounts()
+        self.tasks = Tasks()
 
         self.update_sender_id()
         self.update_sender_password()
@@ -76,6 +77,7 @@ class SageIntacctSDK:
         self.reimbursements.set_sender_id(self.__sender_id)
         self.checking_accounts.set_sender_id(self.__sender_id)
         self.savings_accounts.set_sender_id(self.__sender_id)
+        self.tasks.set_sender_id(self.__sender_id)
 
     def update_sender_password(self):
         """
@@ -101,6 +103,7 @@ class SageIntacctSDK:
         self.reimbursements.set_sender_password(self.__sender_password)
         self.checking_accounts.set_sender_password(self.__sender_password)
         self.savings_accounts.set_sender_password(self.__sender_password)
+        self.tasks.set_sender_password(self.__sender_password)
 
     def update_session_id(self):
         """
@@ -127,3 +130,4 @@ class SageIntacctSDK:
         self.reimbursements.set_session_id(self.__session_id)
         self.checking_accounts.set_session_id(self.__session_id)
         self.savings_accounts.set_session_id(self.__session_id)
+        self.tasks.set_session_id(self.__session_id)
